@@ -1,6 +1,6 @@
 package UV::Handle;
 
-our $VERSION = '1.000004';
+our $VERSION = '1.000005';
 $VERSION = eval $VERSION;
 
 use strict;
@@ -25,7 +25,7 @@ sub BUILD {
 
 sub DEMOLISH {
     my ($self, $in_global_destruction) = @_;
-    $self->close();
+    $self->_destruct($self->closed());
 }
 
 sub _add_event {
@@ -43,7 +43,7 @@ sub close {
     return $self->_close();
 }
 
-sub closed { return shift->{_closed}; }
+sub closed { return (shift->{_closed})? 1: 0; }
 
 sub loop { return shift->{_loop}; }
 
@@ -55,9 +55,6 @@ sub on {
     if ($event && grep {$event eq $_} @{$self->{_events}}) {
         my $cb = ($_[0] && CORE::ref($_[0]) eq 'CODE')? shift: undef;
         $self->{"_on_$event"} = $cb;
-        # if ($self->_has_struct() && $event eq 'close') {
-        #     $self->_store_close_cb($cb);
-        # }
     }
     return $self;
 }
